# coding: utf-8

"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.1.9
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import DeviceServer
from DeviceServer.models.device_led import DeviceLed  # noqa: E501
from DeviceServer.rest import ApiException

class TestDeviceLed(unittest.TestCase):
    """DeviceLed unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DeviceLed
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = DeviceServer.models.device_led.DeviceLed()  # noqa: E501
        if include_optional :
            return DeviceLed(
                led_index = 1, 
                label = 'Example label', 
                state_index = 0, 
                state_count = 1, 
                led_id = 'bf325375-e030-4fcc-aa00-917317c5747701234567891011121314151617181920212223242526272829303132333435', 
                state_label = '0'
            )
        else :
            return DeviceLed(
                led_index = 1,
                led_id = 'bf325375-e030-4fcc-aa00-917317c5747701234567891011121314151617181920212223242526272829303132333435',
        )

    def testDeviceLed(self):
        """Test DeviceLed"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.1.9
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import DeviceServer
from DeviceServer.models.db_upload_firmware_state import DbUploadFirmwareState  # noqa: E501
from DeviceServer.rest import ApiException

class TestDbUploadFirmwareState(unittest.TestCase):
    """DbUploadFirmwareState unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DbUploadFirmwareState
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = DeviceServer.models.db_upload_firmware_state.DbUploadFirmwareState()  # noqa: E501
        if include_optional :
            return DbUploadFirmwareState(
                device_id = 'bf325375-e030-4fcc-aa00-917317c5747701234567891011121314151617181920212223242526272829303132333435', 
                device_serial = 'BF325375E030FCCBA00917317C574773012345678910111213141516171819202122232425262728293031', 
                device_type = '', 
                upload_state = 'IDLE'
            )
        else :
            return DbUploadFirmwareState(
                device_id = 'bf325375-e030-4fcc-aa00-917317c5747701234567891011121314151617181920212223242526272829303132333435',
                device_serial = 'BF325375E030FCCBA00917317C574773012345678910111213141516171819202122232425262728293031',
                device_type = '',
                upload_state = 'IDLE',
        )

    def testDbUploadFirmwareState(self):
        """Test DbUploadFirmwareState"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
